#!/usr/bin/env python
# -*- coding: UTF-8 -*

import urllib

class colors:
    OKGREEN = '\033[92m'
    FAIL = '\033[91m'

def main():
	try: 
		urllib.urlopen('https://google.com') 
		print colors.OKGREEN + u"\u2713" + " Online"
	except:
		print colors.FAIL + u"\u2718" + " Offline" 






import os
from setuptools import setup

setup(name='isonline',
      version='1.0.0',
      description='Check if the internet connection is up',
      keywords='website status website down website up internet check command line too',
      url='http://github.com/akashnimare/isonline/',
      author='Akash Nimare',
      author_email='svnitakash@gmail.com',
      license='MIT',
      packages=['isonline'],
      entry_points = {
        'console_scripts': ['isonline=isonline.auto:main'],
        },
      install_requires=[
            'urllib3'
      ],
      zip_safe=False)

